@@ -197,82 +197,6 @@ def urlenc(**args):
     return buf.getvalue()
 
 
-def wrap_callback(callback):
-    """
-    Converts a row callback into a response callback.
-
-    A row callback is a function that takes rows (arrays of values).
-    A response callback takes raw response chunks (bytestrings).
-    The returned callback will parse a JSON response and invoke
-    the argument on each row discovered.
-
-    Passing in None as the argument is not an error and
-    results in None being returned.
-
-    :param callback: A row callback.
-    :type callback: list -> *
-    :return: A response callback that parses JSON.
-    :rtype: bytestring -> int
-    """
-    if callback is None:
-        return None
-    return RowReader(callback).process
-
-
-class RowReader(object):
-    def __init__(self, callback):
-        self.hasNames = None
-        self.names = None
-        self.skipNextBracket = False
-        self.callback = callback
-        self.backlog = None
-
-    def process(self, string):
-        if self.hasNames is None:
-            self.hasNames = string[0] == "{"
-            if not self.hasNames: self.skipNextBracket = True
-
-        ln = len(string)
-        if self.backlog: string = self.backlog + string
-        pos = [0]
-
-        def useArray(arr):
-            if self.hasNames:
-                if self.names:
-                    self.callback(arr, self.names)
-                else:
-                    self.names = arr
-                    self.skipNextBracket = True
-            else:
-                self.callback(arr, None)
-
-        def takeArrayAt(start):
-            scanned = start + 1
-            while True:
-                end = string.find("]", scanned)
-                if end == -1: return False
-                try:
-                    useArray(decode_json(string[start : end + 1].decode("utf-8")))
-                    pos[0] = end + 1
-                    return True
-                except JsonDecodeError:
-                    scanned = end + 1
-
-        while True:
-            start = string.find("[", pos[0])
-            if self.skipNextBracket:
-                self.skipNextBracket = False
-                pos[0] = start + 1
-            elif start == -1 or not takeArrayAt(start):
-                break
-
-        if pos[0] == 0:
-            self.backlog = string
-            return ln
-        else:
-            self.backlog = None
-            return pos[0]
-
 class SerialConstants(object):
     SO_VECTOR = 1
     SO_STRING = 5
