@@ -1,16 +1,11 @@
-from __future__ import unicode_literals
-from builtins import str
-from builtins import object
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# pylint: disable-msg=C0103
-
 ################################################################################
 # Copyright (c) 2006-2017 Franz Inc.  
 # All rights reserved. This program and the accompanying materials are
 # made available under the terms of the MIT License which accompanies
 # this distribution, and is available at http://opensource.org/licenses/MIT
-################################################################################
+###############################################################################
+from __future__ import unicode_literals
+from builtins import object
 from future.utils import python_2_unicode_compatible
 from past.builtins import unicode
 
